# convert document to the specify format

## How to use

convertto.py --format "format" "file path 1" "file path2"

For example:
```
convertto.py --format "pdf" README.md
```

This will generate the README.pdf in *out* directory